@@ -19,10 +19,11 @@ function_docstring_preprocessing_hooks: List[Callable[[str], str]] = []
 
 
 def _find_str_end(s, start):
-    for i in range(start, len(s)):
-        if i == "\\":  # skip escaped chars
+    for i in range(start + 1, len(s)):
+        c = s[i]
+        if c == "\\":  # skip escaped chars
             continue
-        if i == s[start]:
+        if c == s[start]:
             return i
     return -1
 
@@ -69,7 +70,7 @@ class DirectoryWalkerGuard(object):
 
 
 _default_pybind11_repr_re = re.compile(r'(<(?P<class>\w+(\.\w+)*) object at 0x[0-9a-fA-F]+>)|'
-                                       r'(<(?P<enum>\w+(.\w+)*): \d+>)')
+                                       r'(<(?P<enum>\w+(.\w+)*): -?\d+>)')
 
 
 def replace_default_pybind11_repr(line):
